=====
Trove
=====

.. image:: https://governance.openstack.org/tc/badges/trove.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

Trove is Database as a Service for OpenStack.

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://opendev.org/openstack/trove

For information on how to contribute to trove, please see
CONTRIBUTING.rst_ and HACKING.rst_

.. _CONTRIBUTING.rst: https://opendev.org/openstack/trove/src/branch/master/CONTRIBUTING.rst
.. _HACKING.rst: https://opendev.org/openstack/trove/src/branch/master/HACKING.rst

* `Wiki <https://wiki.openstack.org/wiki/Trove>`_
* `Developer Docs <https://docs.openstack.org/trove/latest/>`_

You can raise bugs here:
`Bug Tracker <https://storyboard.openstack.org/#!/project/openstack/trove>`_

The plan for trove can be found at
`Trove Specs <https://specs.openstack.org/openstack/trove-specs/>`_

Release notes for the project can be found at:
  https://docs.openstack.org/releasenotes/trove

Python client
-------------
Python-troveclient_ is a client for Trove.

.. _Python-troveclient: https://opendev.org/openstack/python-troveclient

Dashboard plugin
----------------
Trove-dashboard_ is OpenStack dashbaord plugin for Trove.

.. _Trove-dashboard: https://opendev.org/openstack/trove-dashboard

References
----------

* `Installation docs`_
* `Manual installation docs`_
* `Build guest image`_

.. _Installation docs: https://docs.openstack.org/trove/latest/install/
.. _Manual installation docs: https://docs.openstack.org/trove/latest/install/install-manual.html
.. _Build guest image: https://docs.openstack.org/trove/latest/admin/building_guest_images.html
